@@ -11,7 +11,7 @@
  * with this package in the file LICENSE, and is available through
  * the world-wide-web at
  * http://www.opensource.org/licenses/bsd-license.php
- * If you did not receive a copy of the new BSDlicense and are unable
+ * If you did not receive a copy of the new BSD license and are unable
  * to obtain it through the world-wide-web, please send a note to
  * pajoye@php.net so we can mail you a copy immediately.
  *
@@ -23,7 +23,7 @@
  * @package  HTML_Template_IT
  * @author   Ulf Wendel <uw@netuse.de>
  * @license  BSD http://www.opensource.org/licenses/bsd-license.php
- * @version  CVS: $Id: IT.php 295605 2010-02-28 22:48:07Z gregorycu $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/packages/HTML_Template_IT
  * @access   public
  */
@@ -48,7 +48,7 @@ define('IT_UNKNOWN_OPTION', -6);
  * one you can build. template::parse() [phplib template = Isotemplate] requests
  * you to name a source and a target where the current block gets parsed into.
  * Source and target can be block names or even handler names. This API gives you
- * a maximum of fexibility but you always have to know what you do which is
+ * a maximum of flexibility but you always have to know what you do which is
  * quite unusual for php skripter like me.
  *
  * I noticed that I do not any control on which block gets parsed into which one.
@@ -278,9 +278,9 @@ class HTML_Template_IT
      * should be preserved although they are empty (no placeholder replaced).
      * Think of a shopping basket. If it's empty you have to drop a message to
      * the user. If it's filled you have to show the contents of
-     * the shopping baseket. Now where do you place the message that the basket
+     * the shopping basket. Now where do you place the message that the basket
      * is empty? It's no good idea to place it in you applications as customers
-     * tend to like unecessary minor text changes. Having another template file
+     * tend to like unnecessary minor text changes. Having another template file
      * for an empty basket means that it's very likely that one fine day
      * the filled and empty basket templates have different layout. I decided
      * to introduce blocks that to not contain any placeholder but only
@@ -288,7 +288,7 @@ class HTML_Template_IT
      *
      * Now if there is no replacement done in such a block the block will
      * be recognized as "empty" and by default ($removeEmptyBlocks = true) be
-     * stripped off. To avoid thisyou can now call touchBlock() to avoid this.
+     * stripped off. To avoid this you can now call touchBlock() to avoid this.
      *
      * The array $touchedBlocks stores a list of touched block which must not
      * be removed even if they are empty.
@@ -299,14 +299,6 @@ class HTML_Template_IT
      */
      var $touchedBlocks = array();
 
-    /**
-     * List of blocks which should not be shown even if not "empty"
-     * @var  array    $_hiddenBlocks
-     * @see  hideBlock(), $removeEmptyBlocks
-     * @access private
-     */
-    var $_hiddenBlocks = array();
-
     /**
      * Variable cache.
      *
@@ -394,7 +386,7 @@ class HTML_Template_IT
     );
 
     /**
-     * Builds some complex regular expressions and optinally sets the
+     * Builds some complex regular expressions and optionally sets the
      * file root directory.
      *
      * Make sure that you call this constructor if you derive your template
@@ -407,7 +399,7 @@ class HTML_Template_IT
      * @see      setRoot()
      * @access   public
      */
-    function HTML_Template_IT($root = '', $options = null)
+     function __construct($root = '', $options = null)
     {
         if (!is_null($options)) {
             $this->setOptions($options);
@@ -748,7 +740,7 @@ class HTML_Template_IT
     /**
      * Sets a variable value.
      *
-     * The function can be used eighter like setVariable( "varname", "value")
+     * The function can be used either like setVariable( "varname", "value")
      * or with one array $variables["varname"] = "value"
      * given setVariable($variables) quite like phplib templates set_var().
      *
@@ -869,7 +861,7 @@ class HTML_Template_IT
     /**
      * Sets the template.
      *
-     * You can eighter load a template file from disk with
+     * You can either load a template file from disk with
      * LoadTemplatefile() or set the template manually using this function.
      *
      * @param string $template               template content
@@ -1002,7 +994,7 @@ class HTML_Template_IT
     } // end func getGlobalvariables
 
     /**
-     * Recusively builds a list of all blocks within the template.
+     * Recursively builds a list of all blocks within the template.
      *
      * @param string $string string that gets scanned
      *
@@ -1065,7 +1057,7 @@ class HTML_Template_IT
      */
     function getFile($filename)
     {
-        if ($filename{0} == '/' && substr($this->fileRoot, -1) == '/') {
+        if ($filename[0] == '/' && substr($this->fileRoot, -1) == '/') {
             $filename = substr($filename, 1);
         }
 
@@ -1088,9 +1080,9 @@ class HTML_Template_IT
         $content = fread($fh, $fsize);
         fclose($fh);
 
-        return preg_replace(
-            "#<!-- INCLUDE (.*) -->#ime",
-            "\$this->getFile('\\1')",
+        return preg_replace_callback(
+            "#<!-- INCLUDE (.*) -->#im",
+            function ($m) { return $this->getFile($m[1]); },
             $content
         );
     } // end func getFile
